@@ -11,6 +11,9 @@ from .acmg import ACMG_COMPLETE_MAP, ACMG_CRITERIA, ACMG_MAP, ACMG_OPTIONS, REV_
 from .case_tags import (
     ANALYSIS_TYPES,
     CANCER_PHENOTYPE_MAP,
+    CASE_REPORT_CASE_FEATURES,
+    CASE_REPORT_CASE_IND_FEATURES,
+    CASE_REPORT_VARIANT_TYPES,
     CASE_SEARCH_TERMS,
     CASE_STATUSES,
     CUSTOM_CASE_REPORTS,
@@ -54,6 +57,7 @@ from .variant_tags import (
     SV_TYPES,
     VARIANT_CALL,
     VARIANT_FILTERS,
+    VARIANT_REPORT_VARIANT_FEATURES,
 )
 from .variants_export import (
     EXPORT_HEADER,
