@@ -292,7 +292,13 @@ def case_diagnosis(institute_id, case_name):
 
     remove = True if request.args.get("remove") == "yes" else False
     store.diagnose(
-        institute_obj, case_obj, user_obj, link, level=level, omim_id=omim_id, remove=remove
+        institute_obj,
+        case_obj,
+        user_obj,
+        link,
+        level=level,
+        omim_id=omim_id,
+        remove=remove,
     )
     return redirect(request.referrer)
 
@@ -336,7 +342,10 @@ def phenotypes(institute_id, case_name, phenotype_id=None):
                 phenotype_inds=phenotype_inds,
             )
         except ValueError:
-            flash(f"Unable to add phenotype for the given terms:{phenotype_term}", "warning")
+            flash(
+                f"Unable to add phenotype for the given terms:{phenotype_term}",
+                "warning",
+            )
             return redirect(case_url)
 
     return redirect("#".join([case_url, "phenotypes_panel"]))
@@ -411,9 +420,13 @@ def phenotypes_actions(institute_id, case_name):
         username = current_app.config["PHENOMIZER_USERNAME"]
         password = current_app.config["PHENOMIZER_PASSWORD"]
         diseases = controllers.hpo_diseases(username, password, hpo_ids)
-        return render_template(
-            "cases/diseases.html", diseases=diseases, institute=institute_obj, case=case_obj
-        )
+        if diseases:
+            return render_template(
+                "cases/diseases.html",
+                diseases=diseases,
+                institute=institute_obj,
+                case=case_obj,
+            )
 
     if action == "DELETE":
         for hpo_id in hpo_ids:
@@ -567,7 +580,10 @@ def pin_variant(institute_id, case_name, variant_id):
     variant_obj = store.variant(variant_id)
     user_obj = store.user(current_user.email)
     link = url_for(
-        "variant.variant", institute_id=institute_id, case_name=case_name, variant_id=variant_id
+        "variant.variant",
+        institute_id=institute_id,
+        case_name=case_name,
+        variant_id=variant_id,
     )
     if request.form["action"] == "ADD":
         store.pin_variant(institute_obj, case_obj, user_obj, link, variant_obj)
@@ -584,14 +600,18 @@ def mark_validation(institute_id, case_name, variant_id):
     user_obj = store.user(current_user.email)
     validate_type = request.form["type"] or None
     link = url_for(
-        "variant.variant", institute_id=institute_id, case_name=case_name, variant_id=variant_id
+        "variant.variant",
+        institute_id=institute_id,
+        case_name=case_name,
+        variant_id=variant_id,
     )
     store.validate(institute_obj, case_obj, user_obj, link, variant_obj, validate_type)
     return redirect(request.referrer or link)
 
 
 @cases_bp.route(
-    "/<institute_id>/<case_name>/<variant_id>/<partial_causative>/causative", methods=["POST"]
+    "/<institute_id>/<case_name>/<variant_id>/<partial_causative>/causative",
+    methods=["POST"],
 )
 def mark_causative(institute_id, case_name, variant_id, partial_causative=False):
     """Mark a variant as confirmed causative."""
@@ -599,14 +619,23 @@ def mark_causative(institute_id, case_name, variant_id, partial_causative=False)
     variant_obj = store.variant(variant_id)
     user_obj = store.user(current_user.email)
     link = url_for(
-        "variant.variant", institute_id=institute_id, case_name=case_name, variant_id=variant_id
+        "variant.variant",
+        institute_id=institute_id,
+        case_name=case_name,
+        variant_id=variant_id,
     )
     if request.form["action"] == "ADD":
         if "partial_causative" in request.form:
             omim_terms = request.form.getlist("omim_select")
             hpo_terms = request.form.getlist("hpo_select")
             store.mark_partial_causative(
-                institute_obj, case_obj, user_obj, link, variant_obj, omim_terms, hpo_terms
+                institute_obj,
+                case_obj,
+                user_obj,
+                link,
+                variant_obj,
+                omim_terms,
+                hpo_terms,
             )
         else:
             store.mark_causative(institute_obj, case_obj, user_obj, link, variant_obj)
@@ -879,7 +908,7 @@ def download_hpo_genes(institute_id, case_name, category):
     phenotype_terms_with_genes = controllers.phenotypes_genes(store, case_obj, is_clinical)
     html_content = ""
     for term_id, term in phenotype_terms_with_genes.items():
-        html_content += f"<hr><strong>{term_id} - {term.get('description')}</strong><br><br>{term.get('genes')}<br>"
+        html_content += f"<hr><strong>{term_id} - {term.get('description')}</strong><br><br><i>{term.get('genes')}</i><br>"
     return render_pdf(
         HTML(string=html_content),
         download_filename=case_obj["display_name"]
@@ -921,7 +950,8 @@ def multiqc(institute_id, case_name):
 
 
 @cases_bp.route(
-    "/<institute_id>/<case_name>/<individual>/upd_regions_images/<image>", methods=["GET", "POST"]
+    "/<institute_id>/<case_name>/<individual>/upd_regions_images/<image>",
+    methods=["GET", "POST"],
 )
 def host_upd_regions_image(institute_id, case_name, individual, image):
     """Generate UPD REGIONS image file paths"""
@@ -929,7 +959,8 @@ def host_upd_regions_image(institute_id, case_name, individual, image):
 
 
 @cases_bp.route(
-    "/<institute_id>/<case_name>/<individual>/upd_sites_images/<image>", methods=["GET", "POST"]
+    "/<institute_id>/<case_name>/<individual>/upd_sites_images/<image>",
+    methods=["GET", "POST"],
 )
 def host_upd_sites_image(institute_id, case_name, individual, image):
     """Generate UPD image file paths"""
@@ -937,7 +968,8 @@ def host_upd_sites_image(institute_id, case_name, individual, image):
 
 
 @cases_bp.route(
-    "/<institute_id>/<case_name>/<individual>/coverage_images/<image>", methods=["GET", "POST"]
+    "/<institute_id>/<case_name>/<individual>/coverage_images/<image>",
+    methods=["GET", "POST"],
 )
 def host_coverage_image(institute_id, case_name, individual, image):
     """Generate Coverage image file paths"""
@@ -945,7 +977,8 @@ def host_coverage_image(institute_id, case_name, individual, image):
 
 
 @cases_bp.route(
-    "/<institute_id>/<case_name>/<individual>/autozygous_images/<image>", methods=["GET", "POST"]
+    "/<institute_id>/<case_name>/<individual>/autozygous_images/<image>",
+    methods=["GET", "POST"],
 )
 def host_autozygous_image(institute_id, case_name, individual, image):
     """Generate Coverage image file paths"""
@@ -953,7 +986,8 @@ def host_autozygous_image(institute_id, case_name, individual, image):
 
 
 @cases_bp.route(
-    "/<institute_id>/<case_name>/<individual>/ideograms/<image>", methods=["GET", "POST"]
+    "/<institute_id>/<case_name>/<individual>/ideograms/<image>",
+    methods=["GET", "POST"],
 )
 def host_chr_image(institute_id, case_name, individual, image):
     """Generate CHR image file paths. Points to servers 'public/static'"""
