@@ -18,9 +18,6 @@ from scout.constants import (
     CANCER_TIER_OPTIONS,
     CHROMOSOMES,
     CHROMOSOMES_38,
-    CLINICAL_FILTER_BASE,
-    CLINICAL_FILTER_BASE_CANCER,
-    CLINICAL_FILTER_BASE_SV,
     DISMISS_VARIANT_OPTIONS,
     MANUAL_RANK_OPTIONS,
     MOSAICISM_OPTIONS,
@@ -36,7 +33,15 @@ from scout.server.blueprints.variant.utils import (
 from scout.server.links import cosmic_links, str_source_link
 from scout.server.utils import case_append_alignments, institute_and_case, user_institutes
 
-from .forms import CancerFiltersForm, FiltersForm, StrFiltersForm, SvFiltersForm, VariantFiltersForm
+from .forms import (
+    FILTERSFORMCLASS,
+    CancerFiltersForm,
+    CancerSvFiltersForm,
+    FiltersForm,
+    StrFiltersForm,
+    SvFiltersForm,
+    VariantFiltersForm,
+)
 
 LOG = logging.getLogger(__name__)
 
@@ -86,7 +91,9 @@ def variants(store, institute_obj, case_obj, variants_query, variant_count, page
             variant_obj["research_assessments"] = get_manual_assessments(variant_obj)
 
             clinical_var_obj = store.variant(
-                case_id=case_obj["_id"], simple_id=variant_obj["simple_id"], variant_type="clinical"
+                case_id=case_obj["_id"],
+                simple_id=variant_obj["simple_id"],
+                variant_type="clinical",
             )
 
         variant_obj["clinical_assessments"] = get_manual_assessments(clinical_var_obj)
@@ -155,7 +162,9 @@ def sv_variants(store, institute_obj, case_obj, variants_query, variant_count, p
         clinical_var_obj = variant_obj
         if variant_obj["variant_type"] == "research":
             clinical_var_obj = store.variant(
-                case_id=case_obj["_id"], simple_id=variant_obj["simple_id"], variant_type="clinical"
+                case_id=case_obj["_id"],
+                simple_id=variant_obj["simple_id"],
+                variant_type="clinical",
             )
         if clinical_var_obj is not None:
             variant_obj["clinical_assessments"] = get_manual_assessments(clinical_var_obj)
@@ -285,7 +294,8 @@ def get_manual_assessments(variant_obj):
                     if not isinstance(reason, int):
                         reason = int(reason)
                     assessment["title"] += "<strong>{}</strong> - {}<br><br>".format(
-                        MOSAICISM_OPTIONS[reason]["label"], MOSAICISM_OPTIONS[reason]["description"]
+                        MOSAICISM_OPTIONS[reason]["label"],
+                        MOSAICISM_OPTIONS[reason]["description"],
                     )
                 assessment["display_class"] = "secondary"
 
@@ -385,7 +395,10 @@ def parse_variant(
             )
 
     variant_obj["comments"] = store.events(
-        institute_obj, case=case_obj, variant_id=variant_obj["variant_id"], comments=True
+        institute_obj,
+        case=case_obj,
+        variant_id=variant_obj["variant_id"],
+        comments=True,
     )
 
     variant_obj["matching_tiered"] = store.matching_tiered(
@@ -490,7 +503,9 @@ def download_str_variants(case_obj, variant_objs):
     )
     # return a csv with the exported variants
     return Response(
-        generate(",".join(DOCUMENT_HEADER), export_lines), mimetype="text/csv", headers=headers
+        generate(",".join(DOCUMENT_HEADER), export_lines),
+        mimetype="text/csv",
+        headers=headers,
     )
 
 
@@ -523,7 +538,9 @@ def download_variants(store, case_obj, variant_objs):
     )
     # return a csv with the exported variants
     return Response(
-        generate(",".join(document_header), export_lines), mimetype="text/csv", headers=headers
+        generate(",".join(document_header), export_lines),
+        mimetype="text/csv",
+        headers=headers,
     )
 
 
@@ -799,7 +816,7 @@ def upload_panel(store, institute_id, case_name, stream):
     return hgnc_symbols
 
 
-def gene_panel_choices(institute_obj, case_obj):
+def gene_panel_choices(store, institute_obj, case_obj):
     """Populates the multiselect containing all the gene panels to be used in variants filtering
     Args:
         institute_obj(dict): an institute dictionary
@@ -811,8 +828,10 @@ def gene_panel_choices(institute_obj, case_obj):
     panel_list = []
     # Add case default panels and the institute-specific panels to the panel select options
     for panel in case_obj.get("panels", []):
-        panel_option = (panel["panel_name"], panel["display_name"])
-        panel_list.append(panel_option)
+        latest_panel = store.gene_panel(panel["panel_name"])
+        if latest_panel is None or not latest_panel.get("hidden", False):
+            panel_option = (panel["panel_name"], panel["display_name"])
+            panel_list.append(panel_option)
 
     institute_choices = institute_obj.get("gene_panels", {})
 
@@ -854,10 +873,10 @@ def populate_filters_form(store, institute_obj, case_obj, user_obj, category, re
     else:
         clinical_filter_panels = default_panels
 
-    FiltersFormClass = VariantFiltersForm
+    FiltersFormClass = FILTERSFORMCLASS[category]
+
     if category == "snv":
-        FiltersFormClass = FiltersForm
-        clinical_filter_dict = CLINICAL_FILTER_BASE
+        clinical_filter_dict = FiltersFormClass.clinical_filter_base
         clinical_filter_dict.update(
             {
                 "gnomad_frequency": str(institute_obj["frequency_cutoff"]),
@@ -865,33 +884,26 @@ def populate_filters_form(store, institute_obj, case_obj, user_obj, category, re
             }
         )
         clinical_filter = MultiDict(clinical_filter_dict)
-    elif category in ("sv", "cancer_sv"):
-        FiltersFormClass = SvFiltersForm
-        clinical_filter_dict = CLINICAL_FILTER_BASE_SV
+    elif category in ("sv", "cancer", "cancer_sv"):
+        clinical_filter_dict = FiltersFormClass.clinical_filter_base
         clinical_filter_dict.update(
             {
                 "gene_panels": clinical_filter_panels,
             }
         )
         clinical_filter = MultiDict(clinical_filter_dict)
-    elif category == "cancer":
-        FiltersFormClass = CancerFiltersForm
-        clinical_filter_dict = CLINICAL_FILTER_BASE_CANCER
-        clinical_filter_dict.update(
-            {
-                "gene_panels": clinical_filter_panels,
-            }
-        )
-        clinical_filter = MultiDict(clinical_filter_dict)
-
-    elif category == "str":
-        FiltersFormClass = StrFiltersForm
 
     if bool(request_form.get("clinical_filter")):
         form = FiltersFormClass(clinical_filter)
     else:
         form = persistent_filter_actions(
-            store, institute_obj, case_obj, user_obj, category, request_form, FiltersFormClass
+            store,
+            institute_obj,
+            case_obj,
+            user_obj,
+            category,
+            request_form,
+            FiltersFormClass,
         )
 
     return form
@@ -1011,7 +1023,10 @@ def populate_sv_filters_form(store, institute_obj, case_obj, category, request_o
     user_obj = store.user(current_user.email)
 
     if request_obj.method == "GET":
-        form = SvFiltersForm(request_obj.args)
+        if category == "sv":
+            form = SvFiltersForm(request_obj.args)
+        elif category == "cancer_sv":
+            form = CancerSvFiltersForm(request_obj.args)
         variant_type = request_obj.args.get("variant_type", "clinical")
         form.variant_type.data = variant_type
         # set chromosome to all chromosomes
@@ -1025,7 +1040,7 @@ def populate_sv_filters_form(store, institute_obj, case_obj, category, request_o
         )
 
     # populate available panel choices
-    form.gene_panels.choices = gene_panel_choices(institute_obj, case_obj)
+    form.gene_panels.choices = gene_panel_choices(store, institute_obj, case_obj)
 
     return form
 
@@ -1217,7 +1232,9 @@ def activate_case(store, institute_obj, case_obj, current_user):
 
         user_obj = store.user(current_user.email)
         case_link = url_for(
-            "cases.case", institute_id=institute_obj["_id"], case_name=case_obj["display_name"]
+            "cases.case",
+            institute_id=institute_obj["_id"],
+            case_name=case_obj["display_name"],
         )
         store.update_status(institute_obj, case_obj, user_obj, "active", case_link)
 
@@ -1236,7 +1253,9 @@ def reset_all_dimissed(store, institute_obj, case_obj):
     user_obj = store.user(current_user.email)
     # Create an associated case-level event
     link = url_for(
-        "cases.case", institute_id=institute_obj["_id"], case_name=case_obj["display_name"]
+        "cases.case",
+        institute_id=institute_obj["_id"],
+        case_name=case_obj["display_name"],
     )
     store.order_dismissed_variants_reset(institute_obj, case_obj, user_obj, link)
 
@@ -1244,7 +1263,11 @@ def reset_all_dimissed(store, institute_obj, case_obj):
     for variant in evaluated_vars:
         if not variant.get("dismiss_variant"):  # not a dismissed variant
             continue
-        link_page = "variant.sv_variant" if variant.get("category") == "sv" else "variant.variant"
+        link_page = (
+            "variant.sv_variant"
+            if variant.get("category") in ("sv", "cancer_sv")
+            else "variant.variant"
+        )
         link = url_for(
             link_page,
             institute_id=institute_obj["_id"],
