@@ -37,6 +37,76 @@ def test_add_existing_case(adapter, case_obj):
         adapter._add_case(case_obj)
 
 
+def test_load_case_existing_case_id(adapter, institute_obj, case_obj, scout_config):
+    """testing adding another case with same _id and no update flag"""
+
+    ## GIVEN an empty database with an isntitute
+    adapter.institute_collection.insert_one(institute_obj)
+    ## AND a case
+    adapter._add_case(case_obj)
+
+    ## GIVEN an attempt to load the same case using the load_case function
+    ## THEN it should raise integrity error
+    with pytest.raises(IntegrityError):
+        adapter.load_case(config_data=scout_config)
+
+
+def test_load_case_existing_display_name(adapter, institute_obj, case_obj, scout_config):
+    """testing adding another case with same institute_id and display_name"""
+
+    ## GIVEN an empty database with an isntitute
+    adapter.institute_collection.insert_one(institute_obj)
+    ## AND a case
+    adapter._add_case(case_obj)
+
+    # GIVEN another case with same institute and display name of first case
+    config2 = copy.deepcopy(scout_config)
+    config2["family"] = "internal_id2"
+
+    # GIVEN an attempt to load the other using the load_case function
+    ## THEN it should raise integrity error
+    with pytest.raises(IntegrityError):
+        adapter.load_case(config_data=config2)
+
+
+def test_load_case_existing_case_different_name(adapter, institute_obj, case_obj, scout_config):
+    """testing updating a case using config file containing a different case display name"""
+
+    ## GIVEN an empty database with an isntitute
+    adapter.institute_collection.insert_one(institute_obj)
+    ## AND a case
+    adapter._add_case(case_obj)
+
+    # GIVEN another case with same _id but different display_name
+    config2 = copy.deepcopy(scout_config)
+    config2["display_name"] = "case2"
+
+    # GIVEN an attempt to update the case using the load_case function
+    ## THEN it should raise integrity error
+    with pytest.raises(IntegrityError):
+        adapter.load_case(config_data=config2, update=True)
+
+
+def test_load_case_existing_case_different_individuals(
+    adapter, institute_obj, case_obj, scout_config
+):
+    """testing updating a case when the new config file contains different individuals information"""
+
+    ## GIVEN an empty database with an isntitute
+    adapter.institute_collection.insert_one(institute_obj)
+    ## AND a case
+    adapter._add_case(case_obj)
+
+    # GIVEN another case with same _id but different individuals information
+    config2 = copy.deepcopy(scout_config)
+    config2["samples"][0]["sample_id"] = "changed_sample_id"
+
+    # GIVEN an attempt to update the case using the load_case function
+    ## THEN it should raise integrity error
+    with pytest.raises(IntegrityError):
+        adapter.load_case(config_data=config2, update=True)
+
+
 def test_get_case(adapter, case_obj):
     ## GIVEN an empty database (no cases)
     assert adapter.case_collection.find_one() is None
