@@ -413,6 +413,7 @@ def cancer_case_obj(request, cancer_parsed_case):
     case["_id"] = cancer_parsed_case["case_id"]
     case["owner"] = cancer_parsed_case["owner"]
     case["has_svvariants"] = True
+    case["status"] = "inactive"
 
     case["individuals"][0]["sex"] = "1"
     case["individuals"][1]["sex"] = "1"
@@ -456,6 +457,7 @@ def case_obj(request, parsed_case):
     case["synopsis"] = ""
     case["updated_at"] = parsed_case["analysis_date"]
     case["delivery_report"] = parsed_case["delivery_report"]
+    case["custom_images"] = parsed_case["custom_images"]["case"]
     case["assignees"] = []
     case["phenotype_terms"] = []  # do not assign any phenotype
     case["cohorts"] = []  # do not assign any cohort
@@ -820,8 +822,7 @@ def real_populated_database(real_panel_database, parsed_case):
 
     LOG.info("Adding case to real adapter")
     case_obj = build_case(parsed_case, adapter)
-    # adapt custom images
-    case_obj["custom_images"] = parse_custom_images(case_obj)
+
     adapter._add_case(case_obj)
 
     return adapter
